@@ -3,9 +3,8 @@ This module implements several useful functions and decorators that can be
 particularly useful for developers. E.g., deprecating methods / classes, etc.
 """
 
-from __future__ import absolute_import
-
 import re
+import sys
 import logging
 import warnings
 import os
@@ -13,14 +12,6 @@ import subprocess
 import multiprocessing
 import functools
 
-__author__ = 'Shyue Ping Ong'
-__copyright__ = "Copyright 2014, The Materials Virtual Lab"
-__version__ = '0.1'
-__maintainer__ = 'Shyue Ping Ong'
-__email__ = 'ongsp@ucsd.edu'
-__date__ = '1/24/14'
-
-
 logger = logging.getLogger(__name__)
 
 
@@ -36,6 +27,7 @@ def deprecated(replacement=None, message=None):
     Returns:
         Original function, but with a warning to use the updated class.
     """
+
     def wrap(old):
         def wrapped(*args, **kwargs):
             msg = "%s is deprecated" % old.__name__
@@ -49,14 +41,15 @@ def deprecated(replacement=None, message=None):
                 msg += "; use %s in %s instead." % (r.__name__, r.__module__)
             if message is not None:
                 msg += "\n" + message
-            warnings.simplefilter('default')
-            warnings.warn(msg, DeprecationWarning, stacklevel=2)
+            warnings.warn(msg, FutureWarning, stacklevel=2)
             return old(*args, **kwargs)
+
         return wrapped
+
     return wrap
 
 
-class requires(object):
+class requires:
     """
     Decorator to mark classes or functions as requiring a specified condition
     to be true. This can be used to present useful error messages for
@@ -77,16 +70,25 @@ class requires(object):
         condition: Condition necessary to use the class or function.
         message: A message to be displayed if the condition is not True.
     """
+
     def __init__(self, condition, message):
+        """
+        :param condition: A expression returning a bool.
+        :param message: Message to display if condition is False.
+        """
         self.condition = condition
         self.message = message
 
     def __call__(self, _callable):
+        """
+        :param _callable: Callable function.
+        """
         @functools.wraps(_callable)
         def decorated(*args, **kwargs):
             if not self.condition:
                 raise RuntimeError(self.message)
             return _callable(*args, **kwargs)
+
         return decorated
 
 
@@ -130,7 +132,7 @@ def get_ncpus():
 
     # jython
     try:
-        from java.lang import Runtime
+        from java.lang import Runtime  # pylint: disable=import-outside-toplevel
         runtime = Runtime.getRuntime()
         res = runtime.availableProcessors()
         if res > 0:
@@ -200,13 +202,13 @@ def install_excepthook(hook_type="color", **kwargs):
     info.
 
     Return:
-        0 if hook is installed successfully. 
+        0 if hook is installed successfully.
     """
     try:
-        from IPython.core import ultratb
+        from IPython.core import ultratb  # pylint: disable=import-outside-toplevel
     except ImportError:
-        import warnings
-        warnings.warn("Cannot install excepthook, IPyhon.core.ultratb not available")
+        warnings.warn(
+            "Cannot install excepthook, IPyhon.core.ultratb not available")
         return 1
 
     # Select the hook.
@@ -218,6 +220,5 @@ def install_excepthook(hook_type="color", **kwargs):
     if hook is None:
         return 2
 
-    import sys
     sys.excepthook = hook(**kwargs)
     return 0
